#!/bin/sh
#
# Patch PE63-0104180 - SuSE 7.1 Linux support
#
# Patch PE63-0104180 fixes a compatibility problem with SuSE Linux 7.1.
# It should be installed after installing HP Eloquence on SuSE Linux 7.1
# or upgrading to SuSE Linux 7.1.
#
# This script is part of patch PE63-0104180 and needs to be executed
# as root after installing the patch.
#
# With SuSE Linux 7.1 the init scripts have been moved from 
# /sbin/init.d to /etc/init.d and the runlevel definitions have
# changed which breaks automatic startup/shutdown of HP Eloquence.
# This patch removes the previous startup script and links and 
# installs the new one.
#

# If /etc/rc.config is present we assume a SuSE Linux 4.4+ distribution
if [ ! -f /etc/rc.config ] ; then
   echo "This patch can only be used with a SuSE Linux 7.1"
   echo " (and above) distribution."
   exit 1
fi

# Check for new SuSE layout
if [ ! -d /etc/init.d ] ; then
   echo "This patch can only be used with a SuSE Linux 7.1"
   echo " (and above) distribution."
   exit 1;
fi

# Remove any previous scripts and links
echo "Removing old startup/shutdown script ..."
/bin/rm -f /sbin/init.d/eloq6
/bin/rm -f /sbin/init.d/rc2.d/K30eloq6
/bin/rm -f /sbin/init.d/rc2.d/S30eloq6
/bin/rm -f /sbin/init.d/rc3.d/K30eloq6
/bin/rm -f /sbin/init.d/rc3.d/S30eloq6

# Install new script and create startup links
echo "Installing new startup/shutdown script ..."
/bin/cp /opt/eloquence6/newconfig/startup/suse/init.eloq6 /etc/init.d/eloq6
/bin/ln -sf ../eloq6 /etc/init.d/rc2.d/K01eloq6
/bin/ln -sf ../eloq6 /etc/init.d/rc2.d/S30eloq6
/bin/ln -sf ../eloq6 /etc/init.d/rc3.d/K01eloq6
/bin/ln -sf ../eloq6 /etc/init.d/rc3.d/S30eloq6
/bin/ln -sf ../eloq6 /etc/init.d/rc5.d/K01eloq6
/bin/ln -sf ../eloq6 /etc/init.d/rc5.d/S30eloq6

echo "done."
